-- Includes
local ScreenManager = require 'lib.screenmanager.ScreenManager'

-- Set Random Seed
love.math.setRandomSeed( os.time() )

-- ------------------------------------------------
-- Local Variables
-- ------------------------------------------------

local showDebug = false

local showLaunchInfo = true

-- ------------------------------------------------
-- Local Functions
-- ------------------------------------------------

local function drawStats()
    love.graphics.setColor(100, 100, 100, 255)
    love.graphics.rectangle('fill', 5, love.graphics.getHeight() - 185, 200, 200)
    love.graphics.setColor(255, 255, 255, 255)
    love.graphics.print(string.format("FT: %.3f ms", 1000 * love.timer.getAverageDelta()), 10, love.graphics.getHeight() - 180)
    love.graphics.print(string.format("FPS: %.3f fps", love.timer.getFPS()), 10, love.graphics.getHeight() - 160)
    love.graphics.print(string.format("MEM: %.3f kb", collectgarbage("count")), 10, love.graphics.getHeight() - 140)

    local stats = love.graphics.getStats()
    love.graphics.print(string.format("Drawcalls: %d", stats.drawcalls), 10, love.graphics.getHeight() - 120)
    love.graphics.print(string.format("Canvas Switches: %d", stats.canvasswitches), 10, love.graphics.getHeight() - 100)
    love.graphics.print(string.format("TextureMemory: %.2f kb", stats.texturememory / 1024), 10, love.graphics.getHeight() - 80)
    love.graphics.print(string.format("Images: %d", stats.images), 10, love.graphics.getHeight() - 60)
    love.graphics.print(string.format("Canvases: %d", stats.canvases), 10, love.graphics.getHeight() - 40)
    love.graphics.print(string.format("Fonts: %d", stats.fonts), 10, love.graphics.getHeight() - 20)
end

-- ------------------------------------------------
-- Callbacks
-- ------------------------------------------------

function love.load()
    if showLaunchInfo  then
        print("===================")
        print(string.format("Title: '%s'", getTitle()))
        print(string.format("Version: %s", getVersion()))
        print(string.format("LOVE Version: %d.%d.%d (%s)", love.getVersion()))
        print(string.format("Resolution: %dx%d", love.graphics.getDimensions()))

        print("\n---- RENDERER  ---- ")
        local name, version, vendor, device = love.graphics.getRendererInfo()
        print(string.format("Name: %s \nVersion: %s \nVendor: %s \nDevice: %s", name, version, vendor, device))

        print("===================")
        print(os.date('%c', os.time()))
        print("===================")
    end

    -- Load screens
    local screens = {
        ['splash']    = require( 'src.screens.intro' ),
        -- ['menu']    = require( 'src.screens.mainmenu' ), -- currently not used
        -- ['options']    = require( 'src.screens.options' ), -- currently not used
        ['game']    = require( 'src.screens.game' ),
        ['gameover']    = require( 'src.screens.gameover' )
    };

    -- Apply the list to the ScreenManager and create the first screen.
    ScreenManager.init( screens, 'splash' )

    -- Register the ScreenManager functions to the LÖVE callbacks so that
    -- they will be called automagically.
    ScreenManager.registerCallbacks()

end

function love.draw()
    if showDebug then
        drawStats()
    end
end

function love.keypressed(key)
    print(key)
    if key == 'f1' then
        showDebug = not showDebug
    end
    if key == 'escape' then
        print('quit')
        love.event.quit()
    end
end