local colors = require 'lib.data.colors'
local shapes = require 'lib.data.shapes'
local jobs = require 'lib.data.jobs'
local ResourceLoader = require 'lib.resourceLoader'

-- ------------------------------------------------
-- Customer Class
-- ------------------------------------------------
local Customer = {}

-- ------------------------------------------------
-- Resource Loading
-- ------------------------------------------------

local images = {}
local fonts = {}

-- Register module with resource manager.
ResourceLoader:register(Customer);

---
-- Load images.
--
function Customer.loadImages()
    images['order'] = ResourceLoader:loadImage('res/customer/companionbots_order.png')
    images['box_back'] = ResourceLoader:loadImage('res/customer/companionbots_packageback.png')
    images['box_front'] = ResourceLoader:loadImage('res/customer/companionbots_packagefront.png')
end

---
-- Load fonts.
--
function Customer.loadFonts()
    fonts['order'] = ResourceLoader:loadFont('res/font/KenVectorFutureThin.ttf', 40)
end

function Customer:new()
    local self = {}
    local color, shape, job, score
    local purchase_robot = nil
    local matches = 0

    function self:newOrder()
        color = colors[love.math.random( 1, #colors )]
        shape = shapes[love.math.random( 1, #shapes )]
        job = jobs[love.math.random( 1, #jobs )]
        score = 0
        purchase_robot = nil
    end

    function self:specs()
        return 'Customer '.. color .. ', ' .. shape .. ', ' .. job;
    end

    -- scoring
    function self:getScore()
        if matches == 3 then
            return 500
        elseif matches == 2 then
            return 200
        elseif matches == 1 then
            return 50
        end
        return 0
    end

    -- matching kills or heals "health"
    function self:matchRobot()
        local health = 0
        if color == purchase_robot:getColor() then
            health = health + 20
            matches = matches + 1
        else
            health = health - 18
        end
        if shape == purchase_robot:getShape() then
            health = health + 20
            matches = matches + 1
        else
            health = health - 18
        end
        if job == purchase_robot:getJob() then
            health = health + 20
            matches = matches + 1
        else
            health = health - 18
        end
        if matches == 3 then
            health = 400
        end

      return health
    end

    function self:selectRobot(robot)
        purchase_robot = robot
    end

    function self:clearRobot()
        purchase_robot = nil
    end

    function self:getSelectedRobot()
        return purchase_robot
    end

    function self:draw(x, y)
        love.graphics.draw(images['order'], x, y)

        -- load this in
        love.graphics.setFont(fonts['order'])
        love.graphics.setColor(0,0,0)
        -- write color
        love.graphics.print(color, x + 115, y + 210)
        -- write shape
        love.graphics.print(shape, x + 115, y + 300)
        -- write job
        if job == 'pet_friendly' then
            love.graphics.print('pet friendly', x + 115, y + 380)
        else
            love.graphics.print(job, x + 115, y + 380)
        end
        -- reset color
        love.graphics.setColor(255,255,255)

        -- Draw Box back
        love.graphics.draw(images['box_back'], x * 2 + 50, y)
        -- Draw Bot?
        if purchase_robot ~= nil then
            purchase_robot:draw(x * 2 + 150, y + 200)
        end
        -- Draw Front
        love.graphics.draw(images['box_front'], x * 2 + 50, y)
    end

    return self;
end

return Customer