local colors = require 'lib.data.colors'
local shapes = require 'lib.data.shapes'
local jobs = require 'lib.data.jobs'
local ResourceLoader = require 'lib.resourceLoader'

-- ------------------------------------------------
-- Robot Class
-- ------------------------------------------------
local Robot = {}

-- ------------------------------------------------
-- Resource Loading
-- ------------------------------------------------

local images = {}
local sounds = {}

-- Register module with resource manager.
ResourceLoader:register(Robot);

---
-- Load images.
--
function Robot.loadImages()
    images['circle'] = ResourceLoader:loadImage('res/robots/companionbots_circlebot.png')
    images['square'] = ResourceLoader:loadImage('res/robots/companionbots_squarebot.png')
    images['triangle'] = ResourceLoader:loadImage('res/robots/companionbots_tribot.png')
    -- images['star'] = ResourceLoader:loadImage('res/robots/companionbots_starbot.png')
    images['pentagram'] = ResourceLoader:loadImage('res/robots/companionbots_pentabot.png')
    images['hexagon'] = ResourceLoader:loadImage('res/robots/companionbots_hexbot.png')

    -- Hook and types
    images['hook'] = ResourceLoader:loadImage('res/robots/companionbots_trackhook.png')
    images['cooking'] = ResourceLoader:loadImage('res/robots/companionbots_tracksign_foodbot.png')
    images['love'] = ResourceLoader:loadImage('res/robots/companionbots_tracksign_lovebot.png')
    images['pet_friendly'] = ResourceLoader:loadImage('res/robots/companionbots_tracksign_petfriendly.png')
    images['social'] = ResourceLoader:loadImage('res/robots/companionbots_tracksign_social.png')
    images['mechanic'] = ResourceLoader:loadImage('res/robots/companionbots_tracksign_repairs.png')

    -- eyes
    images['eyes_01'] = ResourceLoader:loadImage('res/robots/companionbots_eyes_01.png')
    images['eyes_02'] = ResourceLoader:loadImage('res/robots/companionbots_eyes_02.png')
    images['eyes_03'] = ResourceLoader:loadImage('res/robots/companionbots_eyes_03.png')
    images['eyes_04'] = ResourceLoader:loadImage('res/robots/companionbots_eyes_04.png')
    images['eyes_05'] = ResourceLoader:loadImage('res/robots/companionbots_eyes_05.png')
    images['eyes_06'] = ResourceLoader:loadImage('res/robots/companionbots_eyes_06.png')
    images['eyes_07'] = ResourceLoader:loadImage('res/robots/companionbots_eyes_07.png')
end

function Robot.loadSounds()
    sounds['crush'] = ResourceLoader:loadSound('res/sounds/crush.wav')
    sounds['bip'] = ResourceLoader:loadSound('res/sounds/bip.wav')
    sounds['diiip'] = ResourceLoader:loadSound('res/sounds/diiip.wav')
end

function Robot:new()
    local self = {}
    local color, shape, job, fear, rx, ry
    local selected = false
    local hook = true
    local crushed = false
    local maxFear = 5

    function self:init()
        color = colors[love.math.random( 1, #colors )]
        shape = shapes[love.math.random( 1, #shapes )]
        job = jobs[love.math.random( 1, #jobs )]
        fear = 1
    end

    function self:scare()
        if fear < maxFear then
            fear = fear + 1;
        end
    end

    function self:setFear(new_fear)
        if new_fear > maxFear then
            fear = maxFear;
        elseif new_fear < 1 then
            fear = 1;
        else
            fear = new_fear
        end
    end

    function self:isCrushed()
        return crushed
    end

    function self:crush()
        crushed = true
        hook = false
        sounds['crush']:play()
    end

    function self:isSelected()
        return selected
    end

    function self:select()
        selected = true
        hook = false
    end

    function self:putBack()
        selected = false
        hook = true
    end

    function self:beep()
        sounds['bip']:play()
    end

    function self:specs()
        return 'Robot '.. color .. ', ' .. shape .. ', ' .. job .. ', ' .. fear
    end

    function self:draw(x, y)
        rx = x
        ry = y
        -- Draw Hook
        if hook then
            love.graphics.draw(images['hook'], x + 25, y - 200)
            love.graphics.draw(images[job], x + 90, y - 110)
        end

        -- Color and Draw Robot
        if color == 'green' then
            love.graphics.setColor(25,189,35)
        elseif color == 'red' then
            love.graphics.setColor(219,15,26)
        elseif color == 'blue' then
            love.graphics.setColor(77,155,219)
        elseif color == 'yellow' then
            love.graphics.setColor(224,242,22)
        elseif color == 'grey' then
            love.graphics.setColor(176,172,164)
        elseif color == 'brown' then
            love.graphics.setColor(153,115,32)
        end

        love.graphics.draw(images[shape], x, y)

        love.graphics.setColor(255,255,255)

        -- Draw Robot Eyes
        if selected then
            love.graphics.draw(images['eyes_06'], x, y)
        elseif crushed then
            love.graphics.draw(images['eyes_07'], x, y)
        else
            love.graphics.draw(images['eyes_0'..fear], x, y)
        end
    end

    -- ------------------------------------------------
    -- Getters
    -- ------------------------------------------------
    function self:getColor()
        return color
    end

    function self:getShape()
        return shape
    end

    function self:getJob()
        return job
    end

    function self:getFearLevel()
        return fear
    end

    function self:isClicked(x, y)
        if self:isSelected() or self:isCrushed() then
            return false
        end
        if x >= rx and x < rx + images[shape]:getWidth()
        and y >= ry and y < ry + images[shape]:getHeight() then
            return true
        end

        return false
    end

    return self
end

return Robot