local ScreenManager = require 'lib.screenmanager.ScreenManager'
local Screen = require 'lib.screenmanager.Screen'
local Robot = require 'src.entities.robot'
local Customer = require 'src.entities.customer'
local Crusher = require 'src.entities.crusher'
local RobotManager = require 'src.entities.robotManager'
local ResourceLoader = require 'lib.resourceLoader'
local Crusher = require 'src.entities.crusher'
local Score = require 'src.entities.score'

local Game = {}

-- ------------------------------------------------
-- Resource Loading
-- ------------------------------------------------
local music = {}
local images = {}

-- Register module with resource manager.
ResourceLoader:register(Game);

---
-- Load Music.
--
function Game.loadMusic()
    music['main'] = ResourceLoader:loadMusic('res/music/companionGame_v004_mixdown_loop.wav', 'static')
end

---
-- Load Images.
--
function Game.loadImages()
    images['background'] = ResourceLoader:loadImage('res/ui/companionbots_background.png')
    images['button_up'] = ResourceLoader:loadImage('res/ui/companionbots_redbutton_up.png')
    images['button_down'] = ResourceLoader:loadImage('res/ui/companionbots_redbutton_down.png')
    images['health_bar'] = ResourceLoader:loadImage('res/ui/companionbots_healthbar.png')
    images['health_fill'] = ResourceLoader:loadImage('res/ui/companionbots_healthfilll.png')
    images['clock_hand'] = ResourceLoader:loadImage('res/ui/companionbots_clockhand.png')
end

function Game.new()
    local self = Screen.new()
    local robots = {}
    local customer = {}
    local robotLimit = 5
    local robotManager, customer, crusher
    local press = false
    local button_wait = 0
    local full_health = 400
    local current_health = 0
    local score

    ---
    -- Initialises the game screen. Create all the game objects.
    --
    function self:init()
        score = Score:new()
        score:reset()
        current_health = full_health

        -- Generate Robots
        robotManager = RobotManager:new(robotLimit)
        robotManager:assemble(robotLimit) -- assemble X random robots

        -- Generate 1 Customer
        customer = Customer:new()
        customer:newOrder()

        -- Generate Crusher
        crusher = Crusher:new()

        -- Start the main game music
        music['main']:setLooping(true)
        music['main']:play()
    end

    function self:draw()
        -- Draw background first
        love.graphics.draw(images['background'], 0, 0)

        -- draw everything else

        -- Draw health fill
        if current_health == nil then
            current_health = 0
        end
        if current_health < full_health/4 then
            love.graphics.setColor(219,15,26)
        elseif current_health < full_health/2 then
            love.graphics.setColor(221, 215, 44)
        else
            love.graphics.setColor(25,189,35)
        end
        love.graphics.rectangle( 'fill', 1820, 45, 70, current_health )
        love.graphics.setColor(255,255,255)

        -- Draw health bar
        love.graphics.draw(images['health_bar'], 1750, 0)

        -- Draw clock hand
        love.graphics.draw(images['clock_hand'], 1800, 465, 0)
        -- love.graphics.draw(images['clock_hand'], 1900, 458, math.rad(90))
        -- love.graphics.draw(images['clock_hand'], 1900, 560, math.rad(180))
        -- love.graphics.draw(images['clock_hand'], 1800, 558, math.rad(270))

        -- draw button
        if press then
            love.graphics.draw(images['button_down'], 65, 640)
            button_wait = button_wait + 1
            if button_wait == 15 then
                button_wait = 0
                press = false
            end
        else
            love.graphics.draw(images['button_up'], 65, 640)
        end
        -- draw crusher
        crusher:draw(1300,572)

        -- draw robot production line
        local x = 15;
        local y = 200;
        local robots = robotManager:getRobots()
        for index=1, #robots do
            if robots[index] ~= nil then
                --  not robots[index]:isCrushed()
                if not robots[index]:isSelected() then
                    if  not robots[index]:isCrushed() then
                        robots[index]:draw(x, y)
                    end
                end
            end
            x = x + 300
        end
        -- draw customer (order pad) + box
        customer:draw(400,550)

       local x, y = love.mouse.getPosition() -- get the position of the mouse
       love.graphics.print(x..' '..y) -- draw the custom mouse image
    end

    function self:update(dt)
        if current_health == 0 then
            ScreenManager.pop( 'game' )
            ScreenManager.push( 'gameover' , score:getScore())
        end
    end

    function self:mousepressed( x, y, button, istouch )
        if button == 1 then
            -- check if red button was pressed
            if x >= 65 and x < 65 + images['button_up']:getWidth()
            and y >= 640 and y < 640 + images['button_up']:getHeight() then
                -- only progress if a bot was selected for the order
                local box_bot = customer:getSelectedRobot()
                if box_bot ~= nil then
                    press = not press
                    crusher:action()
                    current_health = current_health + customer:matchRobot()
                    score:increaseScore(customer:getScore())
                    -- reset box
                    customer:clearRobot()
                    customer:newOrder()

                    -- kill last bot in the line if it's not the current selected for sale
                    if not robotManager:front():isSelected() then
                        robotManager:destroyFirstRobot()
                        current_health = current_health - 50
                        robotManager:assemble(1)
                    else
                        robotManager:assemble(1)
                    end

                    local robots = robotManager:getRobots()
                    for index=1, #robots do
                        if robots[index] ~= nil then
                            robots[index]:setFear(index)
                        end
                    end

                    if current_health > full_health then
                        current_health = full_health
                    elseif current_health < 0 then
                        current_health = 0
                    end
                    return

                end
            end

            -- check if any robots are clicked

            local robots = robotManager:getRobots()
            for index=1, #robots do
                if robots[index] ~= nil then
                    if robots[index]:isClicked(x,y) then
                        local box_bot = customer:getSelectedRobot()
                        if box_bot ~= nil then
                            box_bot:putBack()
                        end
                        robots[index]:select()
                        customer:selectRobot(robots[index])
                        return
                    end
                end
            end
        end
    end
    return self
end

return Game